Module: RnStack::HybridHelper
- Defined in:
- app/helpers/rn_stack/hybrid_helper.rb
Instance Method Summary collapse
-
#mount_react_component(component_name, props = {}, options = {}) ⇒ Object
A bridge to mount React components within Rails views.
Instance Method Details
#mount_react_component(component_name, props = {}, options = {}) ⇒ Object
A bridge to mount React components within Rails views
4 5 6 7 |
# File 'app/helpers/rn_stack/hybrid_helper.rb', line 4 def mount_react_component(component_name, props = {}, = {}) # Using react-rails react_component helper react_component(component_name, props, ) end |