Class: RnStack::Layout
- Inherits:
-
ViewComponent::Base
- Object
- ViewComponent::Base
- RnStack::Layout
- Defined in:
- app/components/rn_stack/layout.rb
Instance Method Summary collapse
-
#initialize(title: nil) ⇒ Layout
constructor
Base layout component that can be extended by user-defined layouts.
Constructor Details
#initialize(title: nil) ⇒ Layout
Base layout component that can be extended by user-defined layouts
4 5 6 |
# File 'app/components/rn_stack/layout.rb', line 4 def initialize(title: nil) @title = title end |